@@ -1,9 +1,10 @@
 from nux.flows.bijective.affine import *
-from nux.flows.bijective.normalization import *
 from nux.flows.bijective.conv import *
-from nux.flows.bijective.maf import *
-from nux.flows.bijective.nonlinearities import *
-from nux.flows.bijective.reshape import *
 from nux.flows.bijective.coupling import *
+from nux.flows.bijective.igr import *
+from nux.flows.bijective.maf import *
+# from nux.flows.bijective.mixture_cdf import *
+from nux.flows.bijective.nonlinearities import *
+from nux.flows.bijective.normalization import *
+from nux.flows.bijective.reshape import *
 from nux.flows.bijective.spline import *
-from nux.flows.bijective.residual import *
\ No newline at end of file
